@@ -24,6 +24,10 @@ class AuthorizationPending(RuntimeError):
 
 class HHApiClient:
     """Клиент для API hh.ru, который берёт на себя авторизацию и сетевые вызовы"""
+
+    RETRY_ATTEMPTS = 3
+    RETRY_BACKOFF_SECONDS = 1.0
+
     def __init__(self):
         self.access_token = None
         self.refresh_token = None
@@ -251,43 +255,63 @@ class HHApiClient:
         headers = kwargs.setdefault("headers", {})
         headers["Authorization"] = f"Bearer {self.access_token}"
         url = f"{API_BASE_URL}{endpoint}"
-        try:
-            response = requests.request(method, url, **kwargs)
-            response.raise_for_status()
-            if response.status_code in (201, 204):
-                return None
-            return response.json()
-        except requests.HTTPError as e:
-            if e.response.status_code == 401:
+        attempt = 0
+        while True:
+            try:
+                response = requests.request(method, url, **kwargs)
+                response.raise_for_status()
+                if response.status_code in (201, 204):
+                    return None
+                return response.json()
+            except requests.HTTPError as e:
+                if e.response.status_code == 401:
+                    log_to_db(
+                        "WARN", LogSource.API_CLIENT,
+                        f"Получен 401 Unauthorized для {endpoint}. "
+                        "Повторная попытка после обновления токена."
+                    )
+                    try:
+                        self.ensure_active_token()
+                        headers["Authorization"] = f"Bearer {self.access_token}"
+                        response = requests.request(method, url, **kwargs)
+                        response.raise_for_status()
+                        if response.status_code in (201, 204):
+                            return None
+                        return response.json()
+                    except AuthorizationPending:
+                        raise
+                    except Exception as refresh_e:
+                        msg = ("Повторная попытка обновления токена не удалась. "
+                               f"Ошибка: {refresh_e}")
+                        log_to_db("ERROR", LogSource.API_CLIENT, msg)
+                        raise ConnectionError(
+                            "Не удалось обновить токен. "
+                            "Попробуйте пере-авторизоваться."
+                        ) from refresh_e
                 log_to_db(
-                    "WARN", LogSource.API_CLIENT,
-                    f"Получен 401 Unauthorized для {endpoint}. "
-                    "Повторная попытка после обновления токена."
+                    "ERROR", LogSource.API_CLIENT,
+                    f"HTTP ошибка для {method} {endpoint}: "
+                    f"{e.response.status_code} {e.response.text}"
                 )
-                try:
-                    self.ensure_active_token()
-                    headers["Authorization"] = f"Bearer {self.access_token}"
-                    response = requests.request(method, url, **kwargs)
-                    response.raise_for_status()
-                    if response.status_code in (201, 204):
-                        return None
-                    return response.json()
-                except AuthorizationPending:
-                    raise
-                except Exception as refresh_e:
-                    msg = ("Повторная попытка обновления токена не удалась. "
-                           f"Ошибка: {refresh_e}")
-                    log_to_db("ERROR", LogSource.API_CLIENT, msg)
-                    raise ConnectionError(
-                        "Не удалось обновить токен. "
-                        "Попробуйте пере-авторизоваться."
-                    ) from refresh_e
-            log_to_db(
-                "ERROR", LogSource.API_CLIENT,
-                f"HTTP ошибка для {method} {endpoint}: "
-                f"{e.response.status_code} {e.response.text}"
-            )
-            raise e
+                raise e
+            except requests.RequestException as e:
+                attempt += 1
+                if attempt > self.RETRY_ATTEMPTS:
+                    msg = (
+                        "Ошибка соединения с hh.ru. "
+                        "Проверьте подключение к интернету или повторите попытку позже."
+                    )
+                    log_to_db("ERROR", LogSource.API_CLIENT, f"{msg} Детали: {e}")
+                    raise ConnectionError(msg) from e
+                delay = self.RETRY_BACKOFF_SECONDS * attempt
+                log_to_db(
+                    "WARN",
+                    LogSource.API_CLIENT,
+                    f"Сетевая ошибка для {method} {endpoint} (попытка "
+                    f"{attempt}/{self.RETRY_ATTEMPTS}). Повтор через {delay:.1f}с. "
+                    f"Детали: {e}"
+                )
+                sleep(delay)
 
     def get_my_resumes(self):
         return self._request("GET", "/resumes/mine")
@@ -452,6 +476,83 @@ class HHApiClient:
                       f"Сетевая ошибка при отклике на {vacancy_id}: {e}")
             return False, ApiErrorReason.NETWORK_ERROR
 
+    def get_negotiation(self, negotiation_id: str):
+        """Возвращает подробную информацию об отклике/приглашении"""
+        return self._request("GET", f"/negotiations/{negotiation_id}")
+
+    def get_negotiation_messages(
+        self,
+        negotiation_id: str,
+        *,
+        page: int = 0,
+        per_page: int = 50,
+        with_text_only: bool = False,
+    ):
+        """Получает страницу сообщений для указанного отклика"""
+        params = {
+            "page": page,
+            "per_page": per_page,
+            "with_text_only": str(bool(with_text_only)).lower(),
+        }
+        return self._request(
+            "GET",
+            f"/negotiations/{negotiation_id}/messages",
+            params=params,
+        )
+
+    def get_latest_negotiation_messages(
+        self,
+        negotiation_id: str,
+        *,
+        per_page: int = 50,
+        with_text_only: bool = False,
+    ):
+        """
+        Получает последнюю страницу переписки вместе с количеством страниц.
+
+        Делает первый запрос для получения total pages, затем, при необходимости,
+        подтягивает последнюю страницу.
+        """
+        first_page = self.get_negotiation_messages(
+            negotiation_id,
+            page=0,
+            per_page=per_page,
+            with_text_only=with_text_only,
+        )
+        total_pages = max(1, int(first_page.get("pages", 1) or 1))
+        target_page = max(0, total_pages - 1)
+
+        if first_page.get("page") == target_page or target_page == 0:
+            data = first_page
+        else:
+            data = self.get_negotiation_messages(
+                negotiation_id,
+                page=target_page,
+                per_page=per_page,
+                with_text_only=with_text_only,
+            )
+        data.setdefault("pages", total_pages)
+        data.setdefault("page", target_page)
+        data.setdefault("per_page", per_page)
+        return data
+
+    def send_negotiation_message(self, negotiation_id: str, message: str) -> bool:
+        """Отправляет сообщение работодателю в рамках отклика"""
+        payload = {"message": message}
+        try:
+            self._request("POST", f"/negotiations/{negotiation_id}/messages", data=payload)
+            log_to_db(
+                "INFO", LogSource.API_CLIENT,
+                f"Сообщение отправлено в отклик {negotiation_id}."
+            )
+            return True
+        except requests.RequestException as e:
+            log_to_db(
+                "ERROR", LogSource.API_CLIENT,
+                f"Ошибка отправки сообщения в отклик {negotiation_id}: {e}"
+            )
+            return False
+
     def logout(self, profile_name: str):
         delete_profile(profile_name)
         print(f"Профиль '{profile_name}' удален.")
