@@ -1,7 +1,7 @@
 import os
 import json
 from datetime import datetime, timedelta
-from typing import Any, Iterable, Sequence
+from typing import Any, Sequence
 
 from platformdirs import user_data_dir
 from sqlalchemy import (
@@ -99,16 +99,16 @@ def get_default_config() -> dict[str, Any]:
         ConfigKeys.STRIKETHROUGH_APPLIED_VAC: True,
         ConfigKeys.STRIKETHROUGH_APPLIED_VAC_NAME: True,
         ConfigKeys.THEME: "hhcli-base",
-        ConfigKeys.VACANCY_LEFT_PANE_PERCENT: 60,
+        ConfigKeys.VACANCY_LEFT_PANE_PERCENT: 57,
         ConfigKeys.VACANCY_COL_INDEX_WIDTH: 6,
-        ConfigKeys.VACANCY_COL_TITLE_WIDTH: 46,
+        ConfigKeys.VACANCY_COL_TITLE_WIDTH: 50,
         ConfigKeys.VACANCY_COL_COMPANY_WIDTH: 28,
-        ConfigKeys.VACANCY_COL_PREVIOUS_WIDTH: 20,
-        ConfigKeys.HISTORY_LEFT_PANE_PERCENT: 55,
+        ConfigKeys.VACANCY_COL_PREVIOUS_WIDTH: 12,
+        ConfigKeys.HISTORY_LEFT_PANE_PERCENT: 57,
         ConfigKeys.HISTORY_COL_INDEX_WIDTH: 6,
         ConfigKeys.HISTORY_COL_TITLE_WIDTH: 38,
         ConfigKeys.HISTORY_COL_COMPANY_WIDTH: 24,
-        ConfigKeys.HISTORY_COL_STATUS_WIDTH: 16,
+        ConfigKeys.HISTORY_COL_STATUS_WIDTH: 10,
         ConfigKeys.HISTORY_COL_SENT_WIDTH: 4,
         ConfigKeys.HISTORY_COL_DATE_WIDTH: 16,
     }
@@ -210,6 +210,7 @@ negotiation_history = Table(
     Column("employer_name", String),
     Column("status", String),
     Column("reason", String),
+    Column("negotiation_id", String),
     Column("was_delivered", Boolean, nullable=False, server_default="0"),
     Column("applied_at", DateTime, nullable=False),
     UniqueConstraint("vacancy_id", "resume_id", name="uq_negotiation_vacancy_resume"),
@@ -490,7 +491,6 @@ def get_professional_roles_by_ids(role_ids: Sequence[str]) -> list[dict[str, Any
 def init_db():
     global engine
     os.makedirs(DATA_DIR, exist_ok=True)
-    print(f"INFO: База данных используется по пути: {DB_PATH}")
     engine = create_engine(f"sqlite:///{DB_PATH}")
     metadata.create_all(engine)
     ensure_schema_upgrades()
@@ -748,7 +748,7 @@ WHERE profile_name = :profile_name
         history_columns = {row[1] for row in history_info}
 
         needs_rebuild = bool(history_info) and (
-            "id" not in history_columns or "resume_id" not in history_columns
+            "id" not in history_columns or "resume_id" not in history_columns or "negotiation_id" not in history_columns
         )
 
         if needs_rebuild:
@@ -765,6 +765,7 @@ CREATE TABLE negotiation_history_new (
     employer_name TEXT,
     status TEXT,
     reason TEXT,
+    negotiation_id TEXT,
     was_delivered INTEGER NOT NULL DEFAULT 0,
     applied_at DATETIME NOT NULL,
     UNIQUE(vacancy_id, resume_id)
@@ -779,7 +780,7 @@ CREATE TABLE negotiation_history_new (
                         """
 INSERT INTO negotiation_history_new (
     vacancy_id, profile_name, resume_id, resume_title,
-    vacancy_title, employer_name, status, reason, was_delivered, applied_at
+    vacancy_title, employer_name, status, reason, negotiation_id, was_delivered, applied_at
 )
 SELECT
     vacancy_id,
@@ -790,6 +791,7 @@ SELECT
     employer_name,
     status,
     reason,
+    NULL,
     0,
     applied_at
 FROM negotiation_history
@@ -944,6 +946,7 @@ def upsert_negotiation_history(negotiations: list[dict], profile_name: str):
                 "employer_name": vacancy.get('employer', {}).get('name'),
                 "status": status_value,
                 "reason": None,
+                "negotiation_id": str(item.get("id") or ""),
                 "was_delivered": 1 if _status_was_delivered(status_value) else 0,
                 "applied_at": datetime.fromisoformat(
                     item['updated_at'].replace("Z", "+00:00")),
@@ -957,6 +960,7 @@ def upsert_negotiation_history(negotiations: list[dict], profile_name: str):
                     "vacancy_title": values["vacancy_title"],
                     "employer_name": values["employer_name"],
                     "status": values["status"],
+                    "negotiation_id": values["negotiation_id"],
                     "was_delivered": values["was_delivered"],
                     "applied_at": values["applied_at"],
                 }
@@ -1021,17 +1025,98 @@ def load_profile(profile_name: str) -> dict | None:
         return None
 
 def delete_profile(profile_name: str):
+    """Удаляет профиль и все связанные данные (настройки, историю, кеши)."""
+    if not profile_name:
+        return
     with engine.connect() as connection:
-        stmt = delete(profiles).where(profiles.c.profile_name == profile_name)
+        # История откликов
+        connection.execute(delete(negotiation_history).where(negotiation_history.c.profile_name == profile_name))
+        # Конфигурации и связанные таблицы
+        connection.execute(delete(config_professional_roles).where(config_professional_roles.c.profile_name == profile_name))
+        connection.execute(delete(config_negative_keywords).where(config_negative_keywords.c.profile_name == profile_name))
+        connection.execute(delete(config_positive_keywords).where(config_positive_keywords.c.profile_name == profile_name))
+        connection.execute(delete(profile_configs).where(profile_configs.c.profile_name == profile_name))
+        # app_state: активный профиль и время синка истории
+        connection.execute(
+            delete(app_state).where(
+                (app_state.c.key == AppStateKeys.ACTIVE_PROFILE)
+                | (app_state.c.key == f"{AppStateKeys.LAST_NEGOTIATION_SYNC_PREFIX}{profile_name}")
+            )
+        )
+        # Сам профиль
+        connection.execute(delete(profiles).where(profiles.c.profile_name == profile_name))
+        connection.commit()
+
+
+def clear_active_profile(profile_name: str | None = None) -> None:
+    """Очищает активный профиль, если задан или любая запись, если профиль не указан."""
+    with engine.connect() as connection:
+        stmt = delete(app_state).where(app_state.c.key == AppStateKeys.ACTIVE_PROFILE)
+        if profile_name:
+            stmt = stmt.where(app_state.c.value == profile_name)
         connection.execute(stmt)
         connection.commit()
 
+def vacuum_database() -> None:
+    """Упаковывает SQLite и возвращает свободное место на диске."""
+    if not engine:
+        return
+    raw_conn = engine.raw_connection()
+    try:
+        cursor = raw_conn.cursor()
+        try:
+            cursor.execute("VACUUM")
+            raw_conn.commit()
+        finally:
+            cursor.close()
+    finally:
+        raw_conn.close()
+
+def cleanup_vacancy_cache(max_age_days: int = 5) -> int:
+    """Удаляет кэш вакансий старше заданного количества дней."""
+    if not engine:
+        return 0
+    cutoff = datetime.now() - timedelta(days=max_age_days)
+    with engine.connect() as connection:
+        result = connection.execute(delete(vacancy_cache).where(vacancy_cache.c.cached_at < cutoff))
+        connection.commit()
+        removed = result.rowcount or 0
+    if removed:
+        vacuum_database()
+    return removed
+
+
+def cleanup_app_logs(max_age_days: int = 20) -> int:
+    """Удаляет строки логов старше заданного количества дней."""
+    if not engine:
+        return 0
+    cutoff = datetime.now() - timedelta(days=max_age_days)
+    with engine.connect() as connection:
+        result = connection.execute(delete(app_logs).where(app_logs.c.timestamp < cutoff))
+        connection.commit()
+        removed = result.rowcount or 0
+    if removed:
+        vacuum_database()
+    return removed
+
 def get_all_profiles() -> list[dict]:
     with engine.connect() as connection:
         stmt = select(profiles)
         result = connection.execute(stmt).fetchall()
         return [dict(row._mapping) for row in result]
 
+
+def get_db_info() -> dict:
+    """Возвращает сведения о базе и профилях для вывода пользователю."""
+    profiles = get_all_profiles() if engine else []
+    active = get_active_profile_name()
+    return {
+        "db_path": DB_PATH,
+        "profile_count": len(profiles),
+        "active_profile": active,
+        "profiles": [p.get("profile_name") for p in profiles],
+    }
+
 def set_active_profile(profile_name: str):
     with engine.connect() as connection:
         stmt = sqlite_insert(app_state).values(
