@@ -3,7 +3,6 @@
 from .config import ConfigScreen
 from .history import NegotiationHistoryScreen
 from .profile_select import ProfileSelectionScreen
-from .resume_select import ResumeSelectionScreen
 from .search_mode import SearchModeScreen
 from .vacancy_list import VacancyListScreen
 
@@ -11,7 +10,6 @@ __all__ = [
     "ConfigScreen",
     "NegotiationHistoryScreen",
     "ProfileSelectionScreen",
-    "ResumeSelectionScreen",
     "SearchModeScreen",
     "VacancyListScreen",
 ]
